@@ -1,11 +1,10 @@
 use strict;
 use warnings;
 package TestMexp;
-our $VERSION = '0.100050';
 
 use Sub::Exporter::ForMethods qw(method_installer);
 use Sub::Exporter -setup => {
-  exports   => [ qw(foo) ],
+  exports   => [ qw(foo blessed_method) ],
   installer => method_installer,
 };
 
@@ -17,4 +16,10 @@ sub foo {
   Carp::longmess("$self -> foo ( @_ )");
 }
 
+BEGIN {
+  my $sub = sub { };
+  bless $sub, __PACKAGE__;
+  *blessed_method = $sub;
+}
+
 1;
